@@ -34,6 +34,10 @@
 
 #include "pidentd.h"
 
+int debug = 0;
+
+int debug = 0; /* for linking with safeio.o */
+
 static char *keyfile_path = PATH_KEYFILE;
 
 static char
@@ -57,7 +61,7 @@ is_base_64 [] =
     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
 };
 
-static char
+static unsigned char
 to_bin[] =
 {
     0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
