@@ -66,6 +66,29 @@ char *strtok(str, dels)
 }
 #endif
 
+int
+parse_addr(struct sockaddr_gen *addr, char *loc)
+{
+    char *tmp = strrchr(loc,'.');
+    int af;
+
+    if (tmp == NULL)
+	return -1;
+
+    *tmp++ ='\0';
+
+#ifdef HAVE_IPV6
+    SGFAM(*addr) = strchr(loc, ':') != 0 ? AF_INET6 : AF_INET;
+    if (inet_pton(SGFAM(*addr), loc, SGADDRP(*addr)) != 1)
+	return -1;
+#else
+    addr->sin_familiy = AF_INET;
+    addr->sin_addr = inet_addr(loc);
+#endif
+    SGPORT(*addr) = htons(atoi(tmp));
+    return 0;
+}
+
 int
 main(int argc, char **argv)
 {
@@ -120,23 +143,14 @@ main(int argc, char **argv)
 	    continue;
 	}
 	/* parse remote, local address */
-	tmp = strrchr(loc,'.');
-	if (tmp == NULL) {
+	if (parse_addr(&k.local, loc) != 0) {
 	    fprintf(stderr,"Malformed line: %s\n", buf2);
 	    continue;
 	}
-	*tmp++ ='\0';
-	laddr.s_addr = inet_addr(loc);
-	lport = atoi(tmp);
-
-	tmp = strrchr(rem,'.');
-	if (tmp == NULL) {
+	if (parse_addr(&k.remote, rem) != 0) {
 	    fprintf(stderr,"Malformed line: %s\n", buf2);
 	    continue;
 	}
-	*tmp++ ='\0';
-	fport = atoi(tmp);
-	faddr.s_addr = inet_addr(rem);
 
 	k.status = -1;
 	k.euid = -1;
@@ -144,10 +158,10 @@ main(int argc, char **argv)
 	k.pid = -1;
 	k.cmd = NULL;
 	k.argv = NULL;
-        k.remote.sin_port=htons(fport);
-	k.local.sin_port=htons(lport);
-	k.remote.sin_addr=faddr;
-	k.local.sin_addr=laddr;
+
+	lport = ntohs(SGPORT(k.local));
+	fport = ntohs(SGPORT(k.remote));
+
 	for (try = 0; try < 5; try++)
 	  {
 	    k.status = ka_lookup(kp, &k);
