@@ -88,12 +88,12 @@ kernel_thread(void *vp)
 	if (debug)
 	{
 	    fprintf(stderr, "remote = %s:%d\n",
-		    s_inet_ntoa(kp->remote.sin_addr, buf1, sizeof(buf1)),
-		    ntohs(kp->remote.sin_port));
+		    s_inet_ntox(&kp->remote, buf1, sizeof(buf1)),
+		    ntohs(SGPORT(kp->remote)));
 	    
 	    fprintf(stderr, "local = %s:%d\n",
-		    s_inet_ntoa(kp->local.sin_addr, buf1, sizeof(buf1)),
-		    ntohs(kp->local.sin_port));
+		    s_inet_ntox(&kp->local, buf1, sizeof(buf1)),
+		    ntohs(SGPORT(kp->local)));
 	}
 
 	attempt = 0;
